#!/bin/bash

# Check for frameworks -- if not present, fetch them
for TARGET in `ls Makefile.*-* | cut -d '.' -f 2`; do
	OS=`echo ${TARGET} | cut -d '-' -f 1`
	echo -n "Checking for frameworks for ${OS}..."
	if [ -d external-frameworks/${OS} ]; then
		echo " found."
		continue
	fi
	echo " not found.. fetching them..."
	mkdir -p external-frameworks/${OS}
	case $OS in
		leopard)
			OSXBUILD=9J61
		;;
		snowleopard)
			OSXBUILD=10A432
		;;
	esac
	chmod -R u+w external-frameworks/tmp 2>/dev/null
	rm -rf external-frameworks/tmp 2>/dev/null
	mkdir -p external-frameworks/tmp 2>/dev/null
	cd external-frameworks/tmp
	for FRAMEWORK in SecurityTokend.root.tar.gz libsecurity_cdsa_client.root.tar.gz libsecurity_cdsa_utilities.root.tar.gz libsecurity_cssm.root.tar.gz libsecurity_utilities.root.tar.gz; do
		echo "Fetching http://src.macosforge.org/Roots/${OSXBUILD}/${FRAMEWORK} for ${OS}"
		curl http://src.macosforge.org/Roots/${OSXBUILD}/${FRAMEWORK} > ${FRAMEWORK}
		tar xf ${FRAMEWORK}
		chmod -R u+w * 2>/dev/null
		find . -name '*.framework' -exec mv "{}" ../${OS} ";" 2>/dev/null
	done
	cd ../..
	if [ "${OS}" = "leopard" ]; then
		sed 's@void ObjectAcl::Entry::@void @;s@void ObjectAcl::@void @' external-frameworks/leopard/security_cdsa_utilities.framework/Headers/objectacl.h > external-frameworks/leopard/security_cdsa_utilities.framework/Headers/objectacl.h.new
		mv external-frameworks/leopard/security_cdsa_utilities.framework/Headers/objectacl.h.new external-frameworks/leopard/security_cdsa_utilities.framework/Headers/objectacl.h
	fi
done
echo "Cleaning up framework tmp directory..."
rm -rf external-frameworks/tmp 2>/dev/null

# Clean up build before we begin
echo "Cleaning up build directories..."
chmod -R u+w build 2>/dev/null
rm -rf build 2>/dev/null

# Build PKCS11 Binaries
echo "Compiling PKCS11 and libtokend..."
for TARGET in `ls Makefile.*-* | cut -d '.' -f 2`; do
	OS=`echo ${TARGET} | cut -d '-' -f 1`
	ARCH=`echo ${TARGET} | cut -d '-' -f 2`
	mkdir -p build
	mkdir -p build/${OS}
	make clean
	make PLATFORM=${TARGET} || exit 1
	cp pkcs11/PKCS11 build/${OS}/PKCS11.${ARCH}
	make clean
done

# Create PKCS11.tokend from PKCS11.tokend.skel
echo "Building PKCS11.tokend..."
cd build
for OS in *; do
	unset ARGS
	for OBJ in ${OS}/*; do
		ARCH=`echo ${OBJ} | cut -d '.' -f 2`
		ARGS="${ARGS} -arch ${ARCH} ${OBJ}"
	done
	lipo ${ARGS} -create -output ${OS}/PKCS11
	rm ${OS}/PKCS11.*
	cp -Rp ../PKCS11.tokend.skel ${OS}/PKCS11.tokend
	mv ${OS}/PKCS11 ${OS}/PKCS11.tokend/Contents/MacOS/PKCS11
done

exit 0
